# 20221104_src3_dec3476_4822_tuned

full DL1ab production (dec3476 and dec4822 with NSB tuning for src3) with lstchain v0.9.9

## command-line:
```
lstmcpipe_generate_config PathConfigAllSkyFullDL1ab --prod_id 20221104_src3_dec3476_4822_tuned --kwargs source_prod_id=20221027_v0.9.9_base_prod --dec_list dec_3476 dec_4822
```

